@@ -21,8 +21,16 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+if(PTS_IS_CLIENT && is_file('/proc/cpuinfo'))
+{
+	phodevi_cpu::$cpuinfo = PHP_EOL . file_get_contents('/proc/cpuinfo');
+}
+
 class phodevi_cpu extends phodevi_device_interface
 {
+	public static $cpuinfo = false;
+	private static $cpu_flags = -1;
+
 	public static function read_property($identifier)
 	{
 		switch($identifier)
@@ -42,9 +50,6 @@ class phodevi_cpu extends phodevi_device_interface
 			case 'core-count':
 				$property = new phodevi_device_property('cpu_core_count', phodevi::smart_caching);
 				break;
-			case 'power-savings-mode':
-				$property = new phodevi_device_property('cpu_power_savings_mode', phodevi::smart_caching);
-				break;
 		}
 
 		return $property;
@@ -70,9 +75,9 @@ class phodevi_cpu extends phodevi_device_interface
 
 		if(phodevi::is_linux())
 		{
-			if(is_file('/sys/devices/system/cpu/present'))
+			if(is_file('/sys/devices/system/cpu/online'))
 			{
-				$present = pts_file_io::file_get_contents('/sys/devices/system/cpu/present');
+				$present = pts_file_io::file_get_contents('/sys/devices/system/cpu/online');
 
 				if(substr($present, 0, 2) == '0-')
 				{
@@ -87,16 +92,16 @@ class phodevi_cpu extends phodevi_device_interface
 
 			if($info == null)
 			{
-				$info = count(phodevi_linux_parser::read_cpuinfo('processor'));
+				$info = self::cpuinfo_core_count();
 			}
 		}
 		else if(phodevi::is_solaris())
 		{
-			$info = count(explode("\n", trim(shell_exec('psrinfo'))));
+			$info = count(explode(PHP_EOL, trim(shell_exec('psrinfo'))));
 		}
 		else if(phodevi::is_bsd())
 		{
-			$info = intval(phodevi_bsd_parser::read_sysctl('hw.ncpu'));
+			$info = intval(phodevi_bsd_parser::read_sysctl(array('hw.ncpufound', 'hw.ncpu')));
 		}
 		else if(phodevi::is_macosx())
 		{
@@ -113,6 +118,16 @@ class phodevi_cpu extends phodevi_device_interface
 	{
 		return self::cpu_default_frequency() * 1000;
 	}
+	public static function is_genuine($cpu)
+	{
+		/*
+			Real/Genuine CPUs should have:
+			1. Contain more than one word in string
+			2. Check vendor (to avoid QEMU, Virtual CPU, etc): Intel, VIA, AMD, ARM, SPARC
+		*/
+
+		return strpos($cpu, ' ') !== false && strpos($cpu, ' ') != strrpos($cpu, ' ') && strlen($cpu) != strlen(str_ireplace(array('Intel', 'VIA', 'AMD', 'ARM', 'SPARC'), null, $cpu))  && stripos($mobo, 'unknown') === false;
+	}
 	public static function cpu_default_frequency($cpu_core = 0)
 	{
 		// Find out the processor frequency
@@ -125,16 +140,37 @@ class phodevi_cpu extends phodevi_device_interface
 				$info = pts_file_io::file_get_contents('/sys/devices/system/cpu/cpu' . $cpu_core . '/cpufreq/scaling_max_freq');
 				$info = intval($info) / 1000000;
 			}
-			else if(is_file('/proc/cpuinfo')) // fall back for those without cpufreq
+			else if(self::$cpuinfo) // fall back for those without cpufreq
 			{
-				$cpu_speeds = phodevi_linux_parser::read_cpuinfo('cpu MHz');
-				$cpu_core = isset($cpu_speeds[$cpu_core]) ? $cpu_core : 0;
-				$info = isset($cpu_speeds[$cpu_core]) ? ($cpu_speeds[$cpu_core] / 1000) : 0;
+				$cpu_mhz = self::read_cpuinfo_line('cpu MHz');
+				$info = $cpu_mhz / 1000;
 			}
 		}
 		else if(phodevi::is_bsd())
 		{
-			$info = phodevi_bsd_parser::read_sysctl(array('hw.acpi.cpu.px_global', 'machdep.est.frequency.target'));
+			$info = phodevi_bsd_parser::read_sysctl(array('dev.cpu.0.freq_levels'));
+
+			if($info != null)
+			{
+				// Popping the top speed off of dev.cpu.0.freq_levels should be the default/highest supported frequency
+				$info = pts_arrays::first_element(explode(' ', str_replace('/', ' ', $info)));
+
+				if(!is_numeric($info))
+				{
+					$info = null;
+				}
+			}
+
+			if($info == null)
+			{
+				$info = phodevi_bsd_parser::read_sysctl(array('hw.acpi.cpu.px_global', 'machdep.est.frequency.target', 'hw.cpuspeed'));
+			}
+
+			if($info == null)
+			{
+				// dev.cpu.0.freq seems to be the real/current frequency, affected by power management, etc so only use as last fallback
+				$info = phodevi_bsd_parser::read_sysctl(array('dev.cpu.0.freq'));
+			}
 
 			if(is_numeric($info))
 			{
@@ -171,38 +207,6 @@ class phodevi_cpu extends phodevi_device_interface
 
 		return pts_math::set_precision($info, 2);
 	}
-	public static function cpu_power_savings_mode()
-	{
-		// Report string if CPU power savings feature is enabled
-		$return_string = null;
-
-		if(phodevi::is_linux() && is_file('/sys/devices/system/cpu/cpu0/cpufreq/scaling_min_freq') && is_file('/sys/devices/system/cpu/cpu0/cpufreq/scaling_max_freq'))
-		{
-			// if EIST / CnQ is disabled, the cpufreq folder shoudln't be present, but double check by comparing the min and max frequencies
-			$min = pts_file_io::file_get_contents('/sys/devices/system/cpu/cpu0/cpufreq/scaling_min_freq');
-			$max = pts_file_io::file_get_contents('/sys/devices/system/cpu/cpu0/cpufreq/scaling_max_freq');
-
-			if($min < $max)
-			{
-				$cpu = phodevi::read_property('cpu', 'model');
-
-				if(strpos($cpu, 'AMD') !== false)
-				{
-					$return_string = 'AMD CnQ was enabled';
-				}
-				else if(strpos($cpu, 'Intel') !== false)
-				{
-					$return_string = 'Intel SpeedStep Technology was enabled';
-				}
-				else
-				{
-					$return_string = 'The CPU was in a power-savings mode';
-				}
-			}
-		}
-
-		return $return_string;
-	}
 	public static function cpu_model()
 	{
 		// Returns the processor name / frequency information
@@ -210,10 +214,10 @@ class phodevi_cpu extends phodevi_device_interface
 
 		if(phodevi::is_linux())
 		{
-			$physical_cpu_ids = phodevi_linux_parser::read_cpuinfo('physical id');
+			$physical_cpu_ids = phodevi_linux_parser::read_cpuinfo('physical id', self::$cpuinfo);
 			$physical_cpu_count = count(array_unique($physical_cpu_ids));
 
-			$cpu_strings = phodevi_linux_parser::read_cpuinfo(array('model name', 'Processor'));
+			$cpu_strings = phodevi_linux_parser::read_cpuinfo(array('model name', 'Processor'), self::$cpuinfo);
 			$cpu_strings_unique = array_unique($cpu_strings);
 
 			if($physical_cpu_count == 1 || empty($physical_cpu_count))
@@ -312,14 +316,192 @@ class phodevi_cpu extends phodevi_device_interface
 		{
 			$info = 'Unknown';
 		}
-
-		if(($strip_point = strpos($info, '@')) > 0)
+		else
 		{
-			$info = trim(substr($info, 0, $strip_point)); // stripping out the reported freq, since the CPU could be overclocked, etc
+			if(($strip_point = strpos($info, '@')) > 0)
+			{
+				$info = trim(substr($info, 0, $strip_point)); // stripping out the reported freq, since the CPU could be overclocked, etc
+			}
+
+			$info = pts_strings::strip_string($info);
+
+			// It seems Intel doesn't report its name when reporting Pentium hardware
+			if(strpos($info, 'Pentium') !== false && strpos($info, 'Intel') === false)
+			{
+				$info = 'Intel ' . $info;
+			}
+
+			if(substr($info, 0, 5) == 'Intel')
+			{
+				$cpu_words = explode(' ', $info);
+				$cpu_words_count = count($cpu_words);
+
+				// Convert strings like 'Intel Core i7 M 620' -> 'Intel Core i7 620M' and 'Intel Core i7 X 990' -> 'Intel Core i7 990X' to better reflect Intel product marketing names
+				if($cpu_words_count > 4 && is_numeric($cpu_words[($cpu_words_count - 1)]) && strlen($cpu_words[($cpu_words_count - 2)]) == 1 && strlen($cpu_words[($cpu_words_count - 3)]) == 2)
+				{
+					$cpu_words[($cpu_words_count - 1)] .= $cpu_words[($cpu_words_count - 2)];
+					unset($cpu_words[($cpu_words_count - 2)]);
+					$info = implode(' ', $cpu_words);
+				}
+			}
 		}
 
 		return $info;
 	}
+	public static function get_cpu_feature_constants()
+	{
+		return array(
+			'sse2' => 2, // SSE 2
+			'sse3' => 4, // SSE 3
+			'sse4a' => 8, // SSE 4a
+			'sse4_1' => 16, // SSE 4.1
+			'sse4_2' => 32, // SSE 4.2
+			'sse5' => 64, // SSE 5
+			'avx' => 128, // AVX
+			'aes' => 256, // AES
+			'epb' => 512, // EPB
+			'svm' => 1024, // AMD SVM (Virtualization)
+			'vmx' => 2048, // Intel Virtualization
+			'xop' => 4096, // AMD XOP Instruction Set
+			'fma3' => 8192, // FMA3 Instruction Set
+			'fma4' => 16384 // FMA4 Instruction Set
+			);
+	}
+	public static function get_cpu_feature_constant($constant)
+	{
+		$features = self::get_cpu_feature_constants();
+
+		return isset($features[$constant]) ? $features[$constant] : -1;
+	}
+	protected static function read_cpuinfo_line($key, $from_start = true)
+	{
+		$line = false;
+
+		if(($from_start && ($key_pos = strpos(self::$cpuinfo, PHP_EOL . $key)) !== false) || ($key_pos = strrpos(self::$cpuinfo, PHP_EOL . $key)) !== false)
+		{
+			$line = substr(self::$cpuinfo, $key_pos);
+			$line = substr($line, strpos($line, ':') + 1);
+			$line = trim(substr($line, 0, strpos($line, PHP_EOL)));
+		}
+
+		return $line;
+	}
+	public static function set_cpu_feature_flags()
+	{
+		$flags = explode(' ', self::read_cpuinfo_line('flags'));
+
+		self::$cpu_flags = 0;
+		foreach(self::get_cpu_feature_constants() as $feature => $value)
+		{
+			if(in_array($feature, $flags))
+			{
+				// The feature is supported on the CPU
+				self::$cpu_flags |= $value;
+			}
+		}
+	}
+	public static function get_cpu_flags()
+	{
+		if(self::$cpu_flags === -1)
+		{
+			self::set_cpu_feature_flags();
+		}
+
+		return self::$cpu_flags;
+	}
+	public static function instruction_set_extensions()
+	{
+		$constants = self::get_cpu_feature_constants();
+		$cpu_flags = self::get_cpu_flags();
+		$extension_string = null;
+
+		foreach($constants as $feature => $value)
+		{
+			// find maximum SSE version
+			if(substr($feature, 0, 3) == 'sse' && ($cpu_flags & $value))
+			{
+				$extension_string = 'SSE ' . str_replace('_', '.', substr($feature, 3));
+			}
+		}
+
+		// Check for other instruction sets
+		foreach(array('avx', 'xop', 'fma3', 'fma4') as $instruction_set)
+		{
+			if(($cpu_flags & self::get_cpu_feature_constant($instruction_set)))
+			{
+				$extension_string .= ($extension_string != null ? ' + ' : null) . strtoupper($instruction_set);
+			}
+		}
+
+		return $extension_string;
+	}
+	public static function virtualization_technology()
+	{
+		$constants = self::get_cpu_feature_constants();
+		$cpu_flags = self::get_cpu_flags();
+		$virtualitzation_technology = false;
+
+		if(($cpu_flags & self::get_cpu_feature_constant('vmx')))
+		{
+			$virtualitzation_technology = 'VT-x';
+		}
+		else if(($cpu_flags & self::get_cpu_feature_constant('svm')))
+		{
+			$virtualitzation_technology = 'AMD-V';
+		}
+
+		return $virtualitzation_technology;
+	}
+	public static function cpuinfo_core_count()
+	{
+		$core_count = self::read_cpuinfo_line('cpu cores');
+
+		if($core_count == false || !is_numeric($core_count))
+		{
+			$core_count = self::read_cpuinfo_line('core id', false);
+
+			if(is_numeric($core_count))
+			{
+				// cpuinfo 'core id' begins counting at 0
+				$core_count += 1;
+			}
+		}
+
+		if($core_count == false || !is_numeric($core_count))
+		{
+			$core_count = self::cpuinfo_thread_count();
+		}
+
+		return $core_count;
+	}
+	public static function cpuinfo_thread_count()
+	{
+		$thread_count = self::read_cpuinfo_line('processor', false);
+
+		if(is_numeric($thread_count))
+		{
+			// cpuinfo 'processor' begins counting at 0
+			$thread_count += 1;
+		}
+
+		return $thread_count;
+	}
+	public static function cpuinfo_cache_size()
+	{
+		// CPU cache size in KB
+		$cache_size = self::read_cpuinfo_line('cache size');
+
+		if(substr($cache_size, -3) == ' KB')
+		{
+			$cache_size = substr($cache_size, 0, -3);
+		}
+		else
+		{
+			$cache_size = null;
+		}
+
+		return $cache_size;
+	}
 }
 
 ?>
