@@ -48,6 +48,11 @@ class phodevi_disk extends phodevi_device_interface
 
 		return $notes;
 	}
+	public static function is_genuine($disk)
+	{
+		return strpos($disk, ' ') > 1 && strlen($disk) == strlen(str_ireplace(array('VBOX', 'QEMU', 'Virtual'), null, $disk));
+		// pts_strings::string_contains($mobo, pts_strings::CHAR_NUMERIC);
+	}
 	public static function hdd_string()
 	{
 		$disks = array();
@@ -94,6 +99,42 @@ class phodevi_disk extends phodevi_device_interface
 			}
 			while(($disk != false || $i < 9) && $i < 128);
 			// On some systems, the first drive seems to be at dev.ad.8 rather than starting at dev.ad.0
+
+			if(empty($disks) && pts_client::executable_in_path('camcontrol'))
+			{
+				$camcontrol = trim(shell_exec('camcontrol devlist 2>&1'));
+
+				foreach(explode(PHP_EOL, $camcontrol) as $line)
+				{
+					if(substr($line, 0, 1) == '<' && ($model_end = strpos($line, '>')) !== false)
+					{
+						$disk = self::prepend_disk_vendor(substr($line, 1, ($model_end - 1)));
+						array_push($disks, $disk);
+					}
+				}
+			}
+		}
+		else if(phodevi::is_solaris())
+		{
+			if(is_executable('/usr/ddu/bin/i386/hd_detect'))
+			{
+				$hd_detect = explode(PHP_EOL, trim(shell_exec('/usr/ddu/bin/i386/hd_detect -l 2>&1')));
+
+				foreach($hd_detect as $hd_line)
+				{
+					if(isset($hd_line) && ($hd_pos = strpos($hd_line, ':/')) != false)
+					{
+						$disk = trim(substr($hd_line, 0, $hd_pos));
+						$disk = self::prepend_disk_vendor($disk);
+
+						if($disk != 'blkdev')
+						{
+							array_push($disks, $disk);
+						}
+					}
+				}
+			}
+
 		}
 		else if(phodevi::is_linux())
 		{
@@ -115,44 +156,7 @@ class phodevi_disk extends phodevi_device_interface
 					}
 
 					$disk_size = round($disk_size * 512 / 1000000000) . 'GB';
-
-					if(isset($disk_model[4]))
-					{
-						$disk_manufacturer = null;
-						$third_char = substr($disk_model, 2, 1);
-
-						switch(substr($disk_model, 0, 2))
-						{
-							case 'WD':
-								$disk_manufacturer = 'Western Digital';
-								break;
-							case 'MK':
-								$disk_manufacturer = 'Toshiba';
-								break;
-							case 'HT':
-								// 'HD' might be some Hitachi disk drives, but that prefix seems too common
-								$disk_manufacturer = 'Hitachi';
-								break;
-							case 'ST':
-								if($third_char == 'T')
-								{
-									$disk_manufacturer = 'Super Talent';
-								}
-								else if($third_char != 'E')
-								{
-									$disk_manufacturer = 'Seagate';
-								}
-								break;
-						}
-
-						if($disk_manufacturer != null && strpos($disk_model, $disk_manufacturer) === false)
-						{
-							$disk_model = $disk_manufacturer . ' ' . $disk_model;
-						}
-
-						// OCZ SSDs aren't spaced
-						$disk_model = str_replace('OCZ-', 'OCZ ', $disk_model);
-					}
+					$disk_model = self::prepend_disk_vendor($disk_model);
 
 					if(strpos($disk_model, $disk_size . ' ') === false && strpos($disk_model, ' ' . $disk_size) === false && $disk_size != '1GB')
 					{
@@ -220,6 +224,53 @@ class phodevi_disk extends phodevi_device_interface
 
 		return $disks;
 	}
+	protected static function prepend_disk_vendor($disk_model)
+	{
+		if(isset($disk_model[4]))
+		{
+			$disk_manufacturer = null;
+			$third_char = substr($disk_model, 2, 1);
+
+			switch(substr($disk_model, 0, 2))
+			{
+				case 'WD':
+					$disk_manufacturer = 'Western Digital';
+
+					if(substr($disk_model, 0, 4) == 'WDC ')
+					{
+						$disk_model = substr($disk_model, 4);
+					}
+					break;
+				case 'MK':
+					$disk_manufacturer = 'Toshiba';
+					break;
+				case 'HT':
+					// 'HD' might be some Hitachi disk drives, but that prefix seems too common
+					$disk_manufacturer = 'Hitachi';
+					break;
+				case 'ST':
+					if($third_char == 'T')
+					{
+						$disk_manufacturer = 'Super Talent';
+					}
+					else if($third_char != 'E')
+					{
+						$disk_manufacturer = 'Seagate';
+					}
+					break;
+			}
+
+			if($disk_manufacturer != null && strpos($disk_model, $disk_manufacturer) === false)
+			{
+				$disk_model = $disk_manufacturer . ' ' . $disk_model;
+			}
+
+			// OCZ SSDs aren't spaced
+			$disk_model = str_replace('OCZ-', 'OCZ ', $disk_model);
+		}
+
+		return $disk_model;
+	}
 	public static function hdd_scheduler()
 	{
 		$scheduler = null;
