@@ -959,6 +959,28 @@ class phodevi_gpu extends phodevi_device_interface
 				if(!empty($info_pci))
 				{
 					$info = $info_pci;
+
+					if(strpos($info, 'Intel 2nd Generation Core Family') !== false && is_readable('/sys/kernel/debug/dri/0/i915_capabilities'))
+					{
+						// Try to come up with a better non-generic string
+						$i915_caps = file_get_contents('/sys/kernel/debug/dri/0/i915_capabilities');
+						if(($x = strpos($i915_caps, 'gen: ')) !== false)
+						{
+							$gen = substr($i915_caps, ($x + 5));
+							$gen = substr($gen, 0, strpos($gen, PHP_EOL));
+
+							if(is_numeric($gen))
+							{
+								$info = 'Intel Gen' . $gen;
+
+								if(strpos($i915_caps, 'is_mobile: yes') !== false)
+								{
+									$info .= ' Mobile';
+								}
+							}
+						}
+
+					}
 				}
 			}
 
