@@ -85,7 +85,7 @@ class phodevi_motherboard extends phodevi_device_interface
 	public static function is_genuine($mobo)
 	{
 		// the string length check is a short way of making sure none of those strings are found in the motherboard string
-		return strpos($mobo, ' ') > 1 && strlen($mobo) == strlen(str_ireplace(array('Virtual', 'Bochs', '440BX', 'Megatrends', 'Award ', 'Software', 'Xen', 'HVM ', 'Notebook', 'OEM', ' KVM'), null, $mobo)) && stripos($mobo, 'unknown') === false;
+		return strpos($mobo, ' ') > 1 && strlen($mobo) == strlen(str_ireplace(array('Virtual', 'Bochs', '440BX', 'Megatrends', 'Award ', 'Software', 'Xen', 'HVM ', 'Notebook', 'OEM', ' KVM', 'unknown'), null, $mobo)) && !is_numeric(substr($mobo, 0, strpos($mobo, ' ')));
 		// pts_strings::string_contains($mobo, pts_strings::CHAR_NUMERIC);
 	}
 	public static function pci_devices()
@@ -359,7 +359,15 @@ class phodevi_motherboard extends phodevi_device_interface
 		}
 		else if(phodevi::is_bsd())
 		{
-			if(($vendor = phodevi_bsd_parser::read_sysctl('hw.vendor')) != false && ($version = phodevi_bsd_parser::read_sysctl(array('hw.version', 'hw.product'))) != false)
+			$vendor = phodevi_bsd_parser::read_kenv('smbios.system.maker');
+			$product = phodevi_bsd_parser::read_kenv('smbios.system.product');
+			$version = phodevi_bsd_parser::read_kenv('smbios.system.version'); // for at least Lenovo ThinkPads this is where it displays ThinkPad model
+
+			if($vendor != null && ($product != null || $version != null))
+			{
+				$info = $vendor . ' ' . $product . ' ' . $version;
+			}
+			else if(($vendor = phodevi_bsd_parser::read_sysctl('hw.vendor')) != false && ($version = phodevi_bsd_parser::read_sysctl(array('hw.version', 'hw.product'))) != false)
 			{
 				$info = trim($vendor . ' ' . $version);
 			}
