@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2011, Phoronix Media
+	Copyright (C) 2008 - 2011, Michael Larabel
 	phodevi_parser.php: General parsing functions used by different parts of Phodevi that are supported by more than one OS
 
 	This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@ class phodevi_parser
 
 		if(pts_client::executable_in_path('nvidia-settings'))
 		{
-			$info = shell_exec('nvidia-settings --query ' . $attribute . ' 2>&1');
+			$info = shell_exec('nvidia-settings --query ' . $attribute . ' 2> /dev/null');
 
 			if(($pos = strpos($info, pts_strings::last_in_string($attribute, '/'))) > 0 && strpos($info, 'ERROR:') === false)
 			{
@@ -201,6 +201,17 @@ class phodevi_parser
 				$info = substr($glxinfo, $pos + 23);
 				$info = substr($info, 0, strpos($info, "\n"));
 				$info = trim(str_replace(array(' Release'), null, $info));
+
+				// The Catalyst Linux Driver now does something stupid for this string like:
+				//  1.4 (2.1 (3.3.11005 Compatibility Profile Context))
+				if(($pos = strrpos($info, 'Compatibility Profile Context')) !== false && strpos($info, '(') != ($last_p = strrpos($info, '(')))
+				{
+					if(is_numeric(str_replace(array('(', '.', ' '), null, substr($info, 0, $last_p))))
+					{
+						// This looks like a stupid Catalyst driver string, so grab the last GL version reported
+						$info = str_replace(array('(', ')'), null, substr($info, ($last_p + 1)));
+					}
+				}
 			}
 		}
 
