@@ -21,6 +21,11 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+if(PTS_IS_CLIENT)
+{
+	phodevi::initial_setup();
+}
+
 class phodevi
 {
 	private static $device_cache = null;
@@ -278,7 +283,7 @@ class phodevi
 		{
 			$property = call_user_func(array('phodevi_' . $device, 'read_property'), $read_property);
 
-			if(!($property instanceOf phodevi_device_property))
+			if(!($property instanceof phodevi_device_property))
 			{
 				return false;
 			}
@@ -353,6 +358,11 @@ class phodevi
 					break;
 				}
 			}
+
+			if(self::$operating_system != null)
+			{
+				break;
+			}
 		}
 
 		if(self::operating_system() == false)
@@ -361,7 +371,7 @@ class phodevi
 		}
 
 		// OpenGL / graphics detection
-		$graphics_detection = array('NVIDIA', array('ATI', 'fglrx'), array('Mesa', 'SGI'));
+		$graphics_detection = array('NVIDIA', array('ATI', 'AMD', 'fglrx'), array('Mesa', 'SGI'));
 		$opengl_driver = phodevi::read_property('system', 'opengl-vendor') . ' ' . phodevi::read_property('system', 'opengl-driver') . ' ' . phodevi::read_property('system', 'dri-display-driver');
 		$opengl_driver = trim(str_replace('Corporation', null, $opengl_driver)); // Prevents a possible false positive for ATI being in CorporATIon
 
@@ -557,6 +567,10 @@ class phodevi
 	{
 		return self::$graphics['nvidia'];
 	}
+	public static function is_root()
+	{
+		return phodevi::read_property('system', 'username') == 'root';
+	}
 }
 
 ?>
