@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2010, Phoronix Media
-	Copyright (C) 2008 - 2010, Michael Larabel
+	Copyright (C) 2008 - 2011, Phoronix Media
+	Copyright (C) 2008 - 2011, Michael Larabel
 	pts_PassFailGraph.php: An abstract graph object extending pts_Graph for showing results in a pass/fail scenario.
 
 	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,6 @@ class pts_MultiPassFailGraph extends pts_Graph
 	{
 		$this->graph_y_title_hide = true;
 		parent::__construct($result_object, $result_file);
-		$this->graph_type = "MULTI_PASS_FAIL";
 		$this->graph_value_type = "ABSTRACT";
 		$this->graph_hide_identifiers = true;
 	}
@@ -41,12 +40,12 @@ class pts_MultiPassFailGraph extends pts_Graph
 		$graph_height = $this->graph_top_end - $this->graph_top_start - ($vertical_border * 2) - $heading_height;
 		$line_height = floor($graph_height / $identifier_count);
 
-		$pass_color = $this->next_paint_color();
-		$fail_color = $this->next_paint_color();
+		$pass_color = $this->get_paint_color('PASS');
+		$fail_color = $this->get_paint_color('FAIL');
 
 		$main_width = floor($graph_width * .24);
 		$main_font_size = $this->graph_font_size_bars;
-		$main_greatest_length = $this->find_longest_string($this->graph_identifiers);
+		$main_greatest_length = pts_strings::find_longest_string($this->graph_identifiers);
 
 		$width = $main_width - 8;
 		$height = $line_height - 4;
@@ -62,7 +61,7 @@ class pts_MultiPassFailGraph extends pts_Graph
 		$headings = pts_strings::comma_explode($this->graph_y_title);
 		$identifiers_width = floor($identifiers_total_width / count($headings));
 		$headings_font_size = $this->graph_font_size_bars;
-		while(($this->text_string_width($this->find_longest_string($headings), $this->graph_font, $headings_font_size) > ($identifiers_width - 2)) || $this->text_string_height($this->graph_maximum_value, $this->graph_font, $headings_font_size) > ($line_height - 4))
+		while(($this->text_string_width(pts_strings::find_longest_string($headings), $this->graph_font, $headings_font_size) > ($identifiers_width - 2)) || $this->text_string_height($this->graph_maximum_value, $this->graph_font, $headings_font_size) > ($line_height - 4))
 		{
 			$headings_font_size -= 0.5;
 		}
