@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2010, Phoronix Media
-	Copyright (C) 2008 - 2010, Michael Larabel
+	Copyright (C) 2008 - 2011, Phoronix Media
+	Copyright (C) 2008 - 2011, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -67,7 +67,7 @@ class pts_file_io
 				}
 				else
 				{
-					@unlink($to_remove);
+					unlink($to_remove);
 				}
 			}
 			else if(is_dir($to_remove))
@@ -78,7 +78,7 @@ class pts_file_io
 
 		if($remove_root_directory && is_dir($object) && count(pts_file_io::glob($object . '/*')) == 0)
 		{
-			@rmdir($object);
+			rmdir($object);
 		}
 	}
 	function copy($source, $dest)
@@ -103,7 +103,7 @@ class pts_file_io
 			$dir = dir($source);
 			while(($entry = $dir->read()) !== false)
 			{
-				if ($entry == '.' || $entry == '..')
+				if($entry == '.' || $entry == '..')
 				{
 					continue;
 				}
