@@ -53,6 +53,12 @@ class pts_openbenchmarking_client
 			return false;
 		}
 
+		if(defined('NO_NETWORK_COMMUNICATION'))
+		{
+			echo PHP_EOL . 'No network support available.' . PHP_EOL;
+			return false;
+		}
+
 		$composite_xml = $result_file->xml_parser->getXML();
 		$system_log_dir = PTS_SAVE_RESULTS_PATH . $result_file->get_identifier() . '/system-logs/';
 
@@ -105,12 +111,16 @@ class pts_openbenchmarking_client
 				$system_logs_zip = pts_client::create_temporary_file();
 				pts_compression::zip_archive_create($system_logs_zip, $system_log_dir);
 
-				if(filesize($system_logs_zip) < 209920)
+				if(filesize($system_logs_zip) < 614400)
 				{
-					// If it's about 205kb, probably too big
+					// If it's about 600Kb, probably too big
 					$system_logs = base64_encode(file_get_contents($system_logs_zip));
 					$system_logs_hash = sha1($system_logs);
 				}
+				else
+				{
+					trigger_error('The systems log attachment is too large to upload to OpenBenchmarking.org.', E_USER_WARNING);
+				}
 
 				unlink($system_logs_zip);
 			}
@@ -286,8 +296,36 @@ class pts_openbenchmarking_client
 			{
 				copy('/var/cache/phoronix-test-suite/openbenchmarking.org/' . $repo_name . '.index', $index_file);
 			}
+
+			if(!is_file($index_file))
+			{
+				static $reported_read_failure_notice;
+
+				if(!isset($reported_read_failure_notice[$repo_name]))
+				{
+					echo PHP_EOL . 'NOTICE: Failed To Fetch OpenBenchmarking.org Repository Data: ' . $repo_name . PHP_EOL;
+					$reported_read_failure_notice[$repo_name] = true;
+				}
+			}
 		}
 	}
+	public static function fetch_repository_changelog($repo_name)
+	{
+		$index_file = PTS_OPENBENCHMARKING_SCRATCH_PATH . $repo_name . '.changes';
+
+		if(!is_file($index_file) || filemtime($index_file) < (time() - 86400))
+		{
+			// Refresh the repository change-log just once a day should be fine
+			$server_index = pts_openbenchmarking::make_openbenchmarking_request('repo_changes', array('repo' => $repo_name));
+
+			if(json_decode($server_index) != false)
+			{
+				file_put_contents($index_file, $server_index);
+			}
+		}
+
+		return is_file($index_file) ? json_decode(file_get_contents($index_file), true) : false;
+	}
 	public static function download_test_profile($qualified_identifier)
 	{
 		if(is_file(PTS_TEST_PROFILE_PATH . $qualified_identifier . '/test-definition.xml'))
@@ -297,12 +335,12 @@ class pts_openbenchmarking_client
 
 		$file = PTS_OPENBENCHMARKING_SCRATCH_PATH . $qualified_identifier . '.zip';
 
+		$hash_json = pts_openbenchmarking::make_openbenchmarking_request('test_hash', array('i' => $qualified_identifier));
+		$hash_json = json_decode($hash_json, true);
+		$hash_check = isset($hash_json['openbenchmarking']['test']['hash']) ? $hash_json['openbenchmarking']['test']['hash'] : null;  // should also check for ['openbenchmarking']['test']['error'] problems
+
 		if(!is_file($file))
 		{
-			$hash_json = pts_openbenchmarking::make_openbenchmarking_request('test_hash', array('i' => $qualified_identifier));
-			$hash_json = json_decode($hash_json, true);
-			$hash_check = $hash_json['openbenchmarking']['test']['hash'];  // should also check for ['openbenchmarking']['test']['error'] problems
-
 			$test_profile = pts_openbenchmarking::make_openbenchmarking_request('download_test', array('i' => $qualified_identifier));
 
 			if($test_profile != null && ($hash_check == null || $hash_check == sha1($test_profile)))
@@ -336,12 +374,12 @@ class pts_openbenchmarking_client
 
 		$file = PTS_OPENBENCHMARKING_SCRATCH_PATH . $qualified_identifier . '.zip';
 
+		$hash_json = pts_openbenchmarking::make_openbenchmarking_request('suite_hash', array('i' => $qualified_identifier));
+		$hash_json = json_decode($hash_json, true);
+		$hash_check = isset($hash_json['openbenchmarking']['suite']['hash']) ? $hash_json['openbenchmarking']['suite']['hash'] : null;  // should also check for ['openbenchmarking']['suite']['error'] problems
+
 		if(!is_file($file))
 		{
-			$hash_json = pts_openbenchmarking::make_openbenchmarking_request('suite_hash', array('i' => $qualified_identifier));
-			$hash_json = json_decode($hash_json, true);
-			$hash_check = $hash_json['openbenchmarking']['suite']['hash'];  // should also check for ['openbenchmarking']['suite']['error'] problems
-
 			$test_suite = pts_openbenchmarking::make_openbenchmarking_request('download_suite', array('i' => $qualified_identifier));
 
 			if($test_suite != null && ($hash_check == null || $hash_check == sha1($test_suite)))
@@ -452,8 +490,29 @@ class pts_openbenchmarking_client
 				}
 				else
 				{
-					// Assume to use the latest version
-					$version = array_shift($repo_index['tests'][$test]['versions']);
+					// Assume to use the latest version unless something else is installed
+					$available_versions = $repo_index['tests'][$test]['versions'];
+					$version = $available_versions[0]; // the latest version available
+
+					if((pts_c::$test_flags & pts_c::is_run_process))
+					{
+						// Check to see if an older version of the test profile is currently installed
+						foreach($available_versions as $i => $v)
+						{
+							if(is_file(pts_client::test_install_root_path() . $repo . '/' . $test . '-' . $v . '/pts-install.xml'))
+							{
+								$version = $v;
+
+								if($i > 0)
+								{
+									// It's not the latest test profile version available
+									trigger_error($repo . '/' . $test . ': The latest test profile version available for upgrade is ' . $available_versions[0] . ' but version ' . $version . ' is the latest currently installed.', E_USER_WARNING);
+								}
+								break;
+							}
+						}
+					}
+
 					pts_openbenchmarking_client::download_test_profile($repo . '/' . $test . '-' . $version);
 					return $repo . '/' . $test . ($bind_version ? '-' . $version : null);
 				}
