@@ -88,9 +88,20 @@ class pts_render
 	}
 	public static function multi_way_compact(&$result_file, &$result_object, $extra_attributes = null)
 	{
-		if($result_file != null && ($result_file->is_multi_way_comparison() || $result_file->is_results_tracker()))
+		if($result_file == null)
 		{
-			if($result_file->is_multi_way_comparison() && in_array($result_object->test_profile->get_display_format(), array('LINE_GRAPH', 'FILLED_LINE_GRAPH')))
+			return;
+		}
+
+		if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && $result_file->get_system_count() > 8)
+		{
+			// If there's too many lines being plotted on line graph, likely to look messy, so convert to scalar automatically
+			$extra_attributes['compact_to_scalar'] = true;
+		}
+
+		if($result_file->is_multi_way_comparison() || isset($extra_attributes['compact_to_scalar']) || $result_file->is_results_tracker())
+		{
+			if((isset($extra_attributes['compact_to_scalar']) || (false && $result_file->is_multi_way_comparison())) && in_array($result_object->test_profile->get_display_format(), array('LINE_GRAPH', 'FILLED_LINE_GRAPH')))
 			{
 				// Convert multi-way line graph into horizontal box plot
 				if(false)
@@ -100,7 +111,6 @@ class pts_render
 				else
 				{
 					// Turn a multi-way line graph into an averaged bar graph
-
 					$buffer_items = $result_object->test_result_buffer->get_buffer_items();
 					$result_object->test_result_buffer = new pts_test_result_buffer();
 
@@ -121,9 +131,44 @@ class pts_render
 				pts_render::compact_result_file_test_object($result_object, $result_table, $result_file->is_multi_way_inverted(), $extra_attributes);
 			}
 		}
+		else if(in_array($result_object->test_profile->get_display_format(), array('LINE_GRAPH', 'FILLED_LINE_GRAPH')))
+		{
+				// Check to see for line graphs if every result is an array of the same result (i.e. a flat line for every result).
+				// If all the results are just flat lines, you might as well convert it to a bar graph
+				$buffer_items = $result_object->test_result_buffer->get_buffer_items();
+				$all_values_are_flat = false;
+				$flat_values = array();
+
+				foreach($buffer_items as $i => $buffer_item)
+				{
+					$unique_in_buffer = array_unique(explode(',', $buffer_item->get_result_value()));
+					$all_values_are_flat = count($unique_in_buffer) == 1;
+
+					if($all_values_are_flat == false)
+					{
+						break;
+					}
+					$flat_values[$i] = array_pop($unique_in_buffer);
+				}
+
+				if($all_values_are_flat)
+				{
+					$result_object->test_result_buffer = new pts_test_result_buffer();
+					foreach($buffer_items as $i => $buffer_item)
+					{
+						$result_object->test_result_buffer->add_test_result($buffer_item->get_result_identifier(), $flat_values[$i]);
+					}
+
+					$result_object->test_profile->set_display_format('BAR_GRAPH');
+				}
+		}
 	}
 	public static function render_graph_process(&$result_object, &$result_file = null, $save_as = false, $extra_attributes = null)
 	{
+		if(isset($extra_attributes['reverse_result_buffer']))
+		{
+			$result_object->test_result_buffer->buffer_values_reverse();
+		}
 		if(isset($extra_attributes['normalize_result_buffer']))
 		{
 			if(isset($extra_attributes['highlight_graph_values']) && is_array($extra_attributes['highlight_graph_values']) && count($extra_attributes['highlight_graph_values']) == 1)
@@ -138,6 +183,21 @@ class pts_render
 			$result_object->normalize_buffer_values($normalize_against);
 		}
 
+		if($result_file != null)
+		{
+			// Cache the redundant words on identifiers so it's not re-computed on every graph
+			static $redundant_word_cache;
+
+			if(!isset($redundant_word_cache[$result_file->get_title()]))
+			{
+				$redundant_word_cache[$result_file->get_title()] = pts_render::evaluate_redundant_identifier_words($result_file->get_system_identifiers());
+			}
+
+			if($redundant_word_cache[$result_file->get_title()])
+			{
+				$result_object->test_result_buffer->auto_shorten_buffer_identifiers($redundant_word_cache[$result_file->get_title()]);
+			}
+		}
 		self::multi_way_compact($result_file, $result_object, $extra_attributes);
 
 		$display_format = $result_object->test_profile->get_display_format();
@@ -330,6 +390,45 @@ class pts_render
 
 		return $graph;
 	}
+	public static function evaluate_redundant_identifier_words($identifiers)
+	{
+		if(count($identifiers) < 6)
+		{
+			// Probably not worth shortening so few result identifiers
+			return false;
+		}
+
+		// Breakup the an identifier into an array by spaces to be used for comparison
+		$common_segments = explode(' ', pts_arrays::last_element($identifiers));
+
+		if(!isset($common_segments[2]))
+		{
+			// If there aren't at least three words in identifier, probably can't be shortened well
+			return false;
+		}
+
+		foreach($identifiers as &$identifier)
+		{
+			$this_identifier = explode(' ', $identifier);
+
+			foreach($common_segments as $pos => $word)
+			{
+				if(!isset($this_identifier[$pos]) || $this_identifier[$pos] != $word || !isset($word[2]))
+				{
+					// The word isn't the same OR the string is less than three characters (e.g. i7 or HD don't chop off from product names
+					unset($common_segments[$pos]);
+				}
+			}
+
+			if(count($common_segments) == 0)
+			{
+				// There isn't any common words to each identifier in result set
+				return false;
+			}
+		}
+
+		return $common_segments;
+	}
 	public static function generate_overview_object(&$overview_table, $overview_type)
 	{
 		switch($overview_type)
@@ -560,6 +659,7 @@ class pts_render
 				default:
 					$line_graph_type = isset($extra_attributes['filled_line_graph']) ? 'FILLED_LINE_GRAPH' : 'LINE_GRAPH';
 					$mto->test_profile->set_display_format((count($days) < 5 || ($is_tracking == false && !isset($extra_attributes['force_line_graph_compact'])) ? 'BAR_ANALYZE_GRAPH' : $line_graph_type));
+					break;
 			}
 
 			foreach(array_keys($systems) as $system_key)
@@ -614,8 +714,7 @@ class pts_render
 			if(count($identifier_r) != 2 || (isset($identifier[14]) && $identifier[4] == '-' && $identifier[13] == ':'))
 			{
 				// the later check will fix 0000-00-00 00:00 as breaking into date
-				$is_multi_way = false;
-				break;
+				return false;
 			}
 
 			if(false && $is_ordered && $prev_system != null && $prev_system != $identifier_r[0] && isset($systems[$identifier_r[0]]))
@@ -625,8 +724,7 @@ class pts_render
 
 				if($result_file == null)
 				{
-					$is_multi_way = false;
-					break;
+					return false;
 				}
 			}
 
