@@ -211,8 +211,14 @@ class pts_test_result_parser
 			case 'MULTI_PASS_FAIL':
 				$test_result = self::parse_generic_result($test_identifier, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
 				break;
+			case 'BAR_GRAPH':
 			default:
 				$test_result = self::parse_numeric_result($test_identifier, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
+
+				if($test_run_request->test_profile->get_display_format() == 'BAR_GRAPH' && !is_numeric($test_result))
+				{
+					$test_result = false;
+				}
 				break;
 		}
 
@@ -534,6 +540,7 @@ class pts_test_result_parser
 					}
 					else if($search_key != null)
 					{
+						$search_key = trim($search_key);
 						pts_client::test_profile_debug_message('Result Parsing Search Key: ' . $search_key);
 						$result_line = substr($result_output, 0, strpos($result_output, "\n", strrpos($result_output, $search_key)));
 						$start_of_line = strrpos($result_line, "\n");
