@@ -258,6 +258,33 @@ class pts_test_run_manager
 	{
 		$this->results_identifier = self::clean_results_identifier($identifier);
 	}
+	public static function recently_saved_test_results()
+	{
+		$recent_results = array();
+		foreach(pts_file_io::glob(PTS_SAVE_RESULTS_PATH . '*/composite.xml') as $composite)
+		{
+			$recent_results[filemtime($composite)] = basename(dirname($composite));
+		}
+
+		if(count($recent_results) > 0)
+		{
+			krsort($recent_results);
+			$recent_results = array_slice($recent_results, 0, 4, true);
+			$res_length = strlen(pts_strings::find_longest_string($recent_results)) + 2;
+			$current_time = time();
+
+			foreach($recent_results as $m_time => &$recent_result)
+			{
+				$days = floor(($current_time - $m_time) / 86400);
+				$recent_result = sprintf('%-' . $res_length . 'ls [%-ls]', $recent_result, ($days == 0 ? 'Today' : pts_strings::days_ago_format_string($days) . ' old'));
+			}
+			echo PHP_EOL . 'Recently Saved Test Results:' . PHP_EOL;
+			echo pts_user_io::display_text_list($recent_results) . PHP_EOL;
+			return true;
+		}
+
+		return false;
+	}
 	public function prompt_save_name()
 	{
 		if($this->file_name != null)
@@ -280,6 +307,9 @@ class pts_test_run_manager
 		{
 			$is_reserved_word = false;
 
+			// Be of help to the user by showing recently saved test results
+			self::recently_saved_test_results();
+
 			while(empty($proposed_name) || ($is_reserved_word = pts_types::is_test_or_suite($proposed_name)))
 			{
 				if($is_reserved_word)
@@ -330,7 +360,7 @@ class pts_test_run_manager
 
 			foreach($this->tests_to_run as &$run_request)
 			{
-				if($run_request instanceOf pts_test_result && in_array($run_request->get_comparison_hash(), $result_objects))
+				if($run_request instanceof pts_test_result && in_array($run_request->get_comparison_hash(), $result_objects))
 				{
 					$no_repeated_tests = false;
 					break;
@@ -640,6 +670,7 @@ class pts_test_run_manager
 	public static function initial_checks(&$to_run, $test_flags = 0)
 	{
 		// Refresh the pts_client::$display in case we need to run in debug mode
+		$test_flags |= pts_c::is_run_process;
 		pts_client::init_display_mode($test_flags);
 		pts_client::set_test_flags($test_flags);
 		$to_run = pts_types::identifiers_to_objects($to_run);
@@ -781,9 +812,10 @@ class pts_test_run_manager
 					{
 						continue;
 					}
-
 					if($run_object->is_test_installed() == false)
 					{
+						// Check to see if older version of test is currently installed
+						// TODO: show change-log between installed versions and upstream
 						array_push($tests_missing, $run_object);
 						continue;
 					}
@@ -947,7 +979,21 @@ class pts_test_run_manager
 					$auto_description = phodevi::read_property('cpu', 'model') . ' testing with a ' . phodevi::read_name('motherboard') . ' on ' . phodevi::read_property('system', 'operating-system');
 					break;
 				default:
-					$auto_description = phodevi::read_property('cpu', 'model') . ' testing with a ' . phodevi::read_name('motherboard') . ' and ' . phodevi::read_property('gpu', 'model') . ' on ' . phodevi::read_property('system', 'operating-system');
+					if(phodevi::read_property('system', 'system-layer'))
+					{
+						// Virtualization, Wine testing...
+						$auto_description = phodevi::read_property('system', 'system-layer') . ' testing on ' . phodevi::read_property('system', 'operating-system');
+					}
+					else if(phodevi::read_name('motherboard') != null && phodevi::read_property('gpu', 'model') != null)
+					{
+						// Standard description
+						$auto_description = phodevi::read_property('cpu', 'model') . ' testing with a ' . phodevi::read_name('motherboard') . ' and ' . phodevi::read_property('gpu', 'model') . ' on ' . phodevi::read_property('system', 'operating-system');
+					}
+					else
+					{
+						// A virtualized environment or a BSD or other OS where not all hardware info is available...
+						$auto_description = phodevi::read_property('cpu', 'model') . ' testing on ' . phodevi::read_property('system', 'operating-system');
+					}
 					break;
 			}
 		}
@@ -1227,7 +1273,7 @@ class pts_test_run_manager
 
 				$run_index = explode(',', pts_user_io::prompt_text_menu('Select the tests in the virtual suite to run', $virtual_suite_tests, true, true));
 
-				if(count($virtual_suite_tests) > 2 && in_array(count($virtual_suite_tests), $run_index))
+				if(count($virtual_suite_tests) > 2 && in_array((count($virtual_suite_tests) - 1), $run_index))
 				{
 					// The appended 'All Tests In Suite' was selected, so run all
 				}
@@ -1244,10 +1290,13 @@ class pts_test_run_manager
 
 				foreach($virtual_suite_tests as &$test_profile)
 				{
-					// The user is to configure virtual suites manually
-					foreach(self::test_prompts_to_result_objects($test_profile) as $result_object)
+					if($test_profile instanceof pts_test_profile)
 					{
-						$this->add_test_result_object($result_object);
+						// The user is to configure virtual suites manually
+						foreach(self::test_prompts_to_result_objects($test_profile) as $result_object)
+						{
+							$this->add_test_result_object($result_object);
+						}
 					}
 				}
 			}
@@ -1292,7 +1341,7 @@ class pts_test_run_manager
 			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environmental variable, skipping ' . $test_profile);
 			$valid_test_profile = false;
 		}
-		else if($test_profile->is_root_required() && (pts_c::$test_flags & pts_c::batch_mode) && phodevi::read_property('system', 'username') != 'root')
+		else if($test_profile->is_root_required() && (pts_c::$test_flags & pts_c::batch_mode) && phodevi::is_root() == false)
 		{
 			$report_errors && pts_client::$display->test_run_error('Cannot run ' . $test_profile . ' in batch mode as root access is required.');
 			$valid_test_profile = false;
@@ -1350,7 +1399,6 @@ class pts_test_run_manager
 		$test_run_manager->pre_execution_process();
 		$test_run_manager->call_test_runs();
 		$test_run_manager->post_execution_process();
-		echo PHP_EOL;
 
 		return $test_run_manager;
 	}
