@@ -38,7 +38,7 @@ ini_set('memory_limit', '256M');
 
 require(PTS_PATH . 'pts-core/pts-core.php');
 
-if(PTS_MODE != 'CLIENT')
+if(!PTS_IS_CLIENT)
 {
 	// pts-core is acting as a library, return now since no need to run client code
 	return;
@@ -53,9 +53,13 @@ if(ini_get('open_basedir') != false)
 {
 	if(pts_client::open_basedir_check() == false)
 	{
-		echo PHP_EOL . 'ERROR: Your php.ini configuration open_basedir setting is preventing ' . PTS_PATH . ' from loading.' . PHP_EOL;
+		echo PHP_EOL . 'ERROR: The php.ini configuration open_basedir directive is preventing ' . PTS_PATH . ' from loading.' . PHP_EOL;
 		return false;
 	}
+	else
+	{
+		trigger_error('The php.ini configuration is using the "open_basedir" directive, which may prevent some parts of the Phoronix Test Suite from working. See the Phoronix Test Suite documentation for more details and to disable this setting.', E_USER_WARNING);
+	}
 }
 
 // Needed for shutdown functions
@@ -117,8 +121,6 @@ if(QUICK_START == false)
 
 	register_shutdown_function(array('pts_client', 'process_shutdown_tasks'));
 
-	pts_network::client_startup();
-
 	if(pts_client::read_env('PTS_IGNORE_MODULES') == false)
 	{
 		pts_client::module_framework_init(); // Initialize the PTS module system
